@@ -63,5 +63,23 @@ AUDIO_EXTENSIONS = [
     ".xi",
     ".mp3",
     ".opus",
+    ".3gp",
+    ".3g2",
+    ".avi",
+    ".asf",
+    ".flv",
+    ".mp4",
+    ".mov",
+    ".m4v",
+    ".mkv",
+    ".mpg",
+    ".webm",
+    ".f4v",
+    ".wmv",
+    ".wma",
+    ".ogg",
+    ".ogm",
+    ".mxf",
+    ".nut",
 ]
 AudioFolder.EXTENSIONS = AUDIO_EXTENSIONS
